@@ -119,6 +119,32 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
                               )
 
                    ),
+                   navbarMenu("ROC analysis",
+                              tabPanel("ROC",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           rocUI("roc")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("plot_roc"), type="html", loader="loader6"),
+                                           ggplotdownUI("roc"),
+                                           withLoader(DTOutput("table_roc"), type="html", loader="loader6")
+                                         )
+                                       )
+                              ),
+                              tabPanel("Time-dependent ROC",
+                                       sidebarLayout(
+                                         sidebarPanel(
+                                           timerocUI("timeroc")
+                                         ),
+                                         mainPanel(
+                                           withLoader(plotOutput("plot_timeroc"), type="html", loader="loader6"),
+                                           ggplotdownUI("timeroc"),
+                                           withLoader(DTOutput("table_timeroc"), type="html", loader="loader6")
+                                         )
+                                       )
+                              )
+                   ),
                    navbarMenu("Plot",
                               tabPanel("Scatter plot",
                                        sidebarLayout(
@@ -137,6 +163,7 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
                                            kaplanUI("kaplan")
                                          ),
                                          mainPanel(
+                                           optionUI("kaplan"),
                                            withLoader(plotOutput("kaplan_plot"), type="html", loader="loader6"),
                                            ggplotdownUI("kaplan")
                                          )
@@ -407,6 +434,32 @@ jsSurveyGadget <- function(data, nfactor.limit = 20) {
       print(out_kaplan())
     })
 
+
+    out_roc <- callModule(rocModule, "roc", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey)
+
+    output$plot_roc <- renderPlot({
+      print(out_roc()$plot)
+    })
+
+    output$table_roc <- renderDT({
+      datatable(out_roc()$tb, rownames=F, editable = F, extensions= "Buttons",
+                caption = "ROC results",
+                options = c(jstable::opt.tbreg("roctable"), list(scrollX = TRUE)))
+    })
+
+
+
+    out_timeroc <- callModule(timerocModule, "timeroc", data = data, data_label = data.label, data_varStruct = NULL, design.survey = design.survey)
+
+    output$plot_timeroc <- renderPlot({
+      print(out_timeroc()$plot)
+    })
+
+    output$table_timeroc <- renderDT({
+      datatable(out_timeroc()$tb, rownames=F, editable = F, extensions= "Buttons", caption = "ROC results",
+                options = c(jstable::opt.tbreg("timeroctable"), list(scrollX = TRUE)))
+    })
+
   }
 
 
